@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
@@ -16,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-cloudfront-origins",
-    "1.63.0",
+    "1.64.0",
     __name__[0:-6],
-    "aws-cloudfront-origins@1.63.0.jsii.tgz",
+    "aws-cloudfront-origins@1.64.0.jsii.tgz",
 )
 
 __all__ = [
